Compare using maximum mean absolute difference and standard deviation.
[libdcp.git] / src / dcp.h
index 9407c9c79320bee3c42c8210de0bec83d27b0928..1ad56efc1a9a0a89217d787a0d925ee16611b4ae 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -50,11 +50,11 @@ public:
        /** Construct a DCP.
         *  @param directory Directory to write files to.
         *  @param name Name.
-        *  @param content_type Content type.
+        *  @param content_kind Content kind.
         *  @param fps Frames per second.
         *  @param length Length in frames.
         */
-       DCP (std::string directory, std::string name, ContentType content_type, int fps, int length);
+       DCP (std::string directory, std::string name, ContentKind content_kind, int fps, int length);
 
        DCP (std::string directory);
 
@@ -90,6 +90,24 @@ public:
         */
        void write_xml () const;
 
+       std::string name () const {
+               return _name;
+       }
+
+       ContentKind content_kind () const {
+               return _content_kind;
+       }
+
+       int frames_per_second () const {
+               return _fps;
+       }
+
+       int length () const {
+               return _length;
+       }
+
+       std::list<std::string> equals (DCP const & other, EqualityFlags flags, double max_mean, double max_std_dev) const;
+
        /** Emitted with a parameter between 0 and 1 to indicate progress
         *  for long jobs.
         */
@@ -126,8 +144,8 @@ private:
        std::string _directory;
        /** the name of the DCP */
        std::string _name;
-       /** the content type of the DCP */
-       ContentType _content_type;
+       /** the content kind of the DCP */
+       ContentKind _content_kind;
        /** frames per second */
        int _fps;
        /** length in frames */